@@ -24,6 +24,11 @@
 #ifdef  HAVE_RESOLV_H
 extern "C" {
 #include <resolv.h>
+
+#if defined(__APPLE__) && defined(__MACH__)
+#include <arpa/nameser_compat.h>
+#endif
+
 }
 
 #if PACKETSZ > 1024
@@ -67,6 +72,51 @@ srv::srv() : Socket::address()
     count = 0;
 }
 
+uint16_t srv::after(uint16_t prior)
+{
+    uint16_t next = 0;
+    uint16_t current;
+
+    unsigned index = 0;
+    while(index < count) {
+        current = srvlist[index++].priority;
+        if(current > prior && current < next)
+            next = current;
+    }
+    return next;
+}
+
+uint32_t srv::total(uint16_t priority)
+{
+    uint32_t result = 0;
+    unsigned index = 0;
+
+    while(index < count) {
+        if(srvlist[index].priority == priority) {
+            result += srvlist[index].weight;
+        }
+        ++index;
+    }
+    return result;
+}        
+
+struct sockaddr *srv::find(uint16_t priority, uint32_t weight)
+{
+    uint32_t total = 0;
+    unsigned index = 0;
+
+    while(index < count) {
+        if(srvlist[index].priority == priority) {
+            total += srvlist[index].weight;
+            if(total >= weight) {
+                return (struct sockaddr *)&srvlist[index].addr;
+            }
+        }
+        ++index;
+    }
+    return NULL;
+}
+
 void srv::set(const char *uri)
 {
     int protocol = IPPROTO_UDP;
@@ -156,6 +206,7 @@ void srv::set(const char *uri)
     uint16_t acount, qcount;
     unsigned char *mp, *ep, *cp;
     uint16_t type, weight, priority, hport, dlen;
+    srv::address *current = NULL;
 
     if(nosrv)
         goto nosrv;
@@ -232,7 +283,6 @@ void srv::set(const char *uri)
 
         if(sp) {
             uint16_t rand;
-            srv::address *current = NULL;
 
             Random::fill((unsigned char *)&rand, sizeof(rand));
             rand &= 0x7fff;
@@ -310,7 +360,7 @@ struct sockaddr *srv::next(void)
         if(!node || np->priority < node->priority || np->weight > node->weight)
             node = np;
     }
-    if(!np) {
+    if(!node) {
         entry = NULL;
         return NULL;
     }
@@ -338,11 +388,9 @@ voip::context_t srv::route(const char *uri, char *buf, size_t size)
         ctx = service::callback::tls_context;
     }
     else if(eq(uri, "tcp:", 4)) {
-        uri += 4;
         ctx = service::callback::tcp_context;
     }
     else if(eq(uri, "udp:", 4)) {
-        uri += 4;
         ctx = service::callback::udp_context;
     }
 
